[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [33746] trunk/blender/source: minor warnings removed.

Campbell Barton ideasman42 at gmail.com
Fri Dec 17 17:05:40 CET 2010


Revision: 33746
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-blender&revision=33746
Author:   campbellbarton
Date:     2010-12-17 17:05:40 +0100 (Fri, 17 Dec 2010)

Log Message:
-----------
minor warnings removed.

Modified Paths:
--------------
    trunk/blender/source/blender/editors/interface/interface_draw.c
    trunk/blender/source/gameengine/Ketsji/KX_FontObject.cpp

Modified: trunk/blender/source/blender/editors/interface/interface_draw.c
===================================================================
--- trunk/blender/source/blender/editors/interface/interface_draw.c	2010-12-17 16:04:05 UTC (rev 33745)
+++ trunk/blender/source/blender/editors/interface/interface_draw.c	2010-12-17 16:05:40 UTC (rev 33746)
@@ -517,7 +517,7 @@
 	int result = 0;
 	int charmax = G.charmax;
 	
-	/* <builtin> font in use. There are TTF <builtin> and non-TTF <builtin> fonts */
+	/* FO_BUILTIN_NAME font in use. There are TTF FO_BUILTIN_NAME and non-TTF FO_BUILTIN_NAME fonts */
 	if(!strcmp(G.selfont->name, FO_BUILTIN_NAME))
 	{
 		if(G.ui_international == TRUE)

Modified: trunk/blender/source/gameengine/Ketsji/KX_FontObject.cpp
===================================================================
--- trunk/blender/source/gameengine/Ketsji/KX_FontObject.cpp	2010-12-17 16:04:05 UTC (rev 33745)
+++ trunk/blender/source/gameengine/Ketsji/KX_FontObject.cpp	2010-12-17 16:05:40 UTC (rev 33746)
@@ -42,22 +42,22 @@
 								RAS_IRenderTools* rendertools,
 								Object *ob):
 	KX_GameObject(sgReplicationInfo, callbacks),
-	m_rendertools(rendertools),
 	m_object(ob),
 	m_dpi(72),
 	m_resolution(1.f),
-	m_color(ob->col) /* initial color - non-animatable */
+	m_color(ob->col), /* initial color - non-animatable */
+	m_rendertools(rendertools)
 {
 	Curve *text = static_cast<Curve *> (ob->data);
 	m_text = text->str;
 	m_fsize = text->fsize;
 
-	/* <builtin> != "default"					*/
+	/* FO_BUILTIN_NAME != "default"	*/
 	/* I hope at some point Blender (2.5x) can have a single font	*/
 	/* with unicode support for ui and OB_FONT			*/
 	/* once we have packed working we can load the <builtin> font	*/
 	const char* filepath = text->vfont->name;
-	if (strcmp("<builtin>", filepath) == 0)
+	if (strcmp(FO_BUILTIN_NAME, filepath) == 0)
 		filepath = "default";
 
 	/* XXX - if it's packed it will not work. waiting for bdiego (Diego) fix for that. */
@@ -89,7 +89,7 @@
 	/* only draws the text if visible */
 	if(this->GetVisible() == 0) return;
 
-	/* XXX 2DO - handle multiple lines
+	/* XXX 2DO - handle multiple lines */
 	/* HARDCODED MULTIPLICATION FACTOR - this will affect the render resolution directly */
 	float RES = BGE_FONT_RES * m_resolution;
 
@@ -42,22 +42,22 @@
 	/* I hope at some point Blender (2.5x) can have a single font	*/
 	/* with unicode support for ui and OB_FONT			*/
-	/* once we have packed working we can load the <builtin> font	*/
+	/* once we have packed working we can load the FO_BUILTIN_NAME font	*/
 	const char* filepath = text->vfont->name;





More information about the Bf-blender-cvs mailing list